@@ -26,8 +26,8 @@ class MainWindow: public QMainWindow
 {
     Q_OBJECT
 public:
-    explicit MainWindow( const QString &marbleDataPath, QWidget *parent = 0, Qt::WindowFlags flags = 0 );
-    virtual ~MainWindow();
+    explicit MainWindow( const QString &marbleDataPath, QWidget *parent = nullptr, Qt::WindowFlags flags = nullptr );
+    ~MainWindow() override;
     MarbleWidget *marbleWidget();
 
 Q_SIGNALS:
@@ -44,7 +44,7 @@ private Q_SLOTS:
     void displayResult( bool );
 
 protected:
-    void resizeEvent( QResizeEvent *event );
+    void resizeEvent( QResizeEvent *event ) override;
 
 private:
     Private * const d;
