@@ -832,7 +832,7 @@ Vec3 HorEqu (double jd, double ep2, double lat, double lng, Vec3 r)
 /*--------------------- Function AppPos ----------------------------------*/
 
 void AppPos (double jd, double ep2, double lat, double lng, double ht,
-				 int solsys, Vec3 r, double& azim, double& elev, double& dist)
+				 int solsys, const Vec3& r, double& azim, double& elev, double& dist)
  {
   /* get apparent position in the horizontal system
 	  jd = MJD-time (UT)
@@ -841,7 +841,7 @@ void AppPos (double jd, double ep2, double lat, double lng, double ht,
 	  ht : height above normal in meters.
 	  solsys : = 1 if object is in solar system and parallax has to be
 						taken into account, 0 otherwise.
-	  r = vector of celestial object. The unit of lenght of this vector
+	  r = vector of celestial object. The unit of length of this vector
 			has to be in terms of the equatorial Earth radius (6378.14 km)
 			if solsys = 1, otherwise it's arbitrary.
 	  azim : azimuth in radians (0 is to the North).
@@ -1402,7 +1402,7 @@ Vec3 Sun200::position (double t)   // position of the Sun at time t
 void Sun200::state (double t, Vec3& rs, Vec3& vs)
  {
   /* State vector rs (position) and vs (velocity) of the Sun in
-	  ecliptic of date coordinates at time t (in Julian Centruries
+	  ecliptic of date coordinates at time t (in Julian Centuries
 	  since J2000).
 	 */
 	 const double  p2 = 2.0 * M_PI;
@@ -2283,7 +2283,7 @@ int Eclipse::lunar (double jd, double tdut)
 	/* (the factor 1.02 allows for enlargment of shadow due to
 		 Earth's atmosphere) */
 
-	// get angular seperation of center of shadow and Moon
+	// get angular separation of center of shadow and Moon
 	r2 = abs(rm);
 	sep = dot(rs,rm)/(abs(rs)*r2);
 	if (fabs(sep) > 1.0) sep = 1.0;
