@@ -70,8 +70,8 @@ class CurrentLocationWidgetPrivate
 };
 
 CurrentLocationWidgetPrivate::CurrentLocationWidgetPrivate()
-    : m_widget( 0 ),
-      m_adjustNavigation( 0 ),
+    : m_widget( nullptr ),
+      m_adjustNavigation( nullptr ),
       m_positionProviderPlugins(),
       m_currentPosition(),
       m_lastOpenPath(),
@@ -111,7 +111,7 @@ void CurrentLocationWidget::setMarbleWidget( MarbleWidget *widget )
 
     const PluginManager* pluginManager = d->m_widget->model()->pluginManager();
     d->m_positionProviderPlugins = pluginManager->positionProviderPlugins();
-    foreach( const PositionProviderPlugin *plugin, d->m_positionProviderPlugins ) {
+    for( const PositionProviderPlugin *plugin: d->m_positionProviderPlugins ) {
         d->m_currentLocationUi.positionTrackingComboBox->addItem( plugin->guiString() );
     }
     if ( d->m_positionProviderPlugins.isEmpty() ) {
@@ -307,8 +307,8 @@ void CurrentLocationWidgetPrivate::receiveGpsCoordinates( const GeoDataCoordinat
     const QString altitudeString = QString( "%1 %2" ).arg( altitude, 0, 'f', 1, QChar(' ') ).arg( altitudeUnitString );
     const QString distanceString = QString( "%1 %2" ).arg( length, 0, 'f', 1, QChar(' ') ).arg( distanceUnitString );
 
-    html = html.arg( position.lonToString() ).arg( position.latToString() );
-    html = html.arg(altitudeString).arg(speedString + QLatin1Char(' ') + unitString);
+    html = html.arg( position.lonToString(), position.latToString() );
+    html = html.arg(altitudeString, speedString + QLatin1Char(' ') + unitString);
     html = html.arg( distanceString );
     m_currentLocationUi.locationLabel->setText( html );
     m_currentLocationUi.showTrackCheckBox->setEnabled( true );
@@ -318,7 +318,7 @@ void CurrentLocationWidgetPrivate::receiveGpsCoordinates( const GeoDataCoordinat
 
 void CurrentLocationWidgetPrivate::changePositionProvider( const QString &provider )
 {
-    foreach( const PositionProviderPlugin* plugin, m_positionProviderPlugins ) {
+    for( const PositionProviderPlugin* plugin: m_positionProviderPlugins ) {
         if ( plugin->guiString() == provider ) {
             m_currentLocationUi.locationLabel->setEnabled( true );
             PositionProviderPlugin* instance = plugin->newInstance();
@@ -331,7 +331,7 @@ void CurrentLocationWidgetPrivate::changePositionProvider( const QString &provid
 
     // requested provider not found -> disable position tracking
     m_currentLocationUi.locationLabel->setEnabled( false );
-    m_widget->model()->positionTracking()->setPositionProviderPlugin( 0 );
+    m_widget->model()->positionTracking()->setPositionProviderPlugin( nullptr );
     m_widget->update();
 }
 
