@@ -13,13 +13,16 @@
 #define MARBLE_LAYERINTERFACE_H
 
 #include "marble_export.h"
-#include "RenderState.h"
+
+#include <QtGlobal>
 
 class QStringList;
 class QString;
 
 namespace Marble {
 
+class RenderState;
+
 class GeoPainter;
 class GeoSceneLayer;
 class ViewportParams;
@@ -36,7 +39,7 @@ public:
      *
      * Gives a preferred level in the existing layer stack where
      * the render() method of this plugin should get executed.
-     *.
+     *
      * Possible Values:
      * "NONE"
      * "STARS"
