@@ -29,17 +29,18 @@ class MARBLE_EXPORT LegendWidget : public QWidget
     Q_OBJECT
 
  public:
-    explicit LegendWidget( QWidget *parent = 0, Qt::WindowFlags f = 0 );
-    ~LegendWidget();
+    explicit LegendWidget( QWidget *parent = nullptr, Qt::WindowFlags f = nullptr );
+    ~LegendWidget() override;
 
     /**
-     * @brief Set a MarbleWidget associated to this widget.
-     * @param widget  the MarbleWidget to be set.
+     * @brief Set a MarbleModel associated to this widget.
+     * @param model  the MarbleModel to be set.
      */
     void setMarbleModel( MarbleModel *model );
 
  Q_SIGNALS:
     void propertyValueChanged( const QString &propertyName, bool value );
+    void tourLinkClicked( const QString &url );
 
  private:
     Q_DISABLE_COPY( LegendWidget )
