@@ -32,11 +32,11 @@ class MercatorScanlineTextureMapper : public TextureMapperInterface
  public:
     explicit MercatorScanlineTextureMapper( StackedTileLoader *tileLoader );
 
-    virtual void mapTexture( GeoPainter *painter,
+    void mapTexture( GeoPainter *painter,
                              const ViewportParams *viewport,
                              int tileZoomLevel,
                              const QRect &dirtyRect,
-                             TextureColorizer *texColorizer );
+                             TextureColorizer *texColorizer ) override;
 
  private:
     void mapTexture( const ViewportParams *viewport, int tileZoomLevel, MapQuality mapQuality );
