@@ -29,8 +29,8 @@ class MARBLE_EXPORT MovieCaptureDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit MovieCaptureDialog(MarbleWidget *widget, QWidget *parent = 0);
-    ~MovieCaptureDialog();
+    explicit MovieCaptureDialog(MarbleWidget *widget, QWidget *parent = nullptr);
+    ~MovieCaptureDialog() override;
 
 public Q_SLOTS:
     void startRecording();
