@@ -10,13 +10,16 @@
 //
 #include "Planet.h"
 
-#include <QString>
-
 #include "PlanetFactory.h"
 #include "MarbleDebug.h"
 #include "MarbleGlobal.h"
 #include "MarbleColors.h"
 
+#include "src/lib/astro/solarsystem.h"
+
+#include <QDateTime>
+#include <QString>
+
 namespace Marble
 {
 
@@ -29,6 +32,7 @@ public:
     qreal epsilon; // obliquity of the ecliptic plane
     qreal theta_0, theta_1; // for calculating sidereal time
     qreal radius; //in metres
+    qreal twilightZone;
     QString name, id; //localized and nonlocalized names
     bool atmosphere;
     QColor atmosphereColor;
@@ -38,6 +42,7 @@ public:
         Pi(0.0), epsilon(0.0),
         theta_0(0.0), theta_1(0.0),
         radius(10000000.0),
+        twilightZone(0),
         name(), id(),
         atmosphere(false)
     {
@@ -140,6 +145,11 @@ qreal Planet::radius() const
     return d->radius;
 }
 
+qreal Planet::twilightZone() const
+{
+    return d->twilightZone;
+}
+
 
 QString Planet::name() const
 {
@@ -151,6 +161,28 @@ QString Planet::id() const
     return d->id;
 }
 
+void Planet::sunPosition(qreal &lon, qreal &lat, const QDateTime &dateTime) const
+{
+    SolarSystem sys;
+    sys.setCurrentMJD(
+                dateTime.date().year(), dateTime.date().month(), dateTime.date().day(),
+                dateTime.time().hour(), dateTime.time().minute(),
+                (double)dateTime.time().second());
+    const QString pname = d->id.at(0).toUpper() + d->id.right(d->id.size() - 1);
+    QByteArray name = pname.toLatin1();
+    sys.setCentralBody( name.data() );
+
+    double ra = 0.0;
+    double decl = 0.0;
+    sys.getSun(ra, decl);
+
+    double _lon = 0.0;
+    double _lat = 0.0;
+    sys.getPlanetographic(ra, decl, _lon, _lat);
+
+    lon = _lon * DEG2RAD;
+    lat = _lat * DEG2RAD;
+}
 
     /* Setter functions */
 void Planet::setM_0( qreal M_0 )
@@ -211,6 +243,11 @@ void Planet::setRadius( qreal radius )
     d->radius = radius;
 }
 
+void Planet::setTwilightZone(qreal twilightZone)
+{
+    d->twilightZone = twilightZone;
+}
+
 void Planet::setName( const QString& name )
 {
     d->name = name;
