@@ -11,6 +11,7 @@
 
 #include "SearchInputWidget.h"
 
+#include "GeoDataCoordinates.h"
 #include "MarblePlacemarkModel.h"
 
 #include <QCompleter>
@@ -24,7 +25,7 @@ SearchInputWidget::SearchInputWidget( QWidget *parent ) :
     m_areaSearch( false )
 {
     updatePlaceholderText();
-    QPixmap const decorator = QPixmap( ":/icons/16x16/edit-find.png" );
+    QPixmap const decorator = QPixmap(QStringLiteral(":/icons/16x16/edit-find.png"));
     Q_ASSERT( !decorator.isNull() );
     setDecorator( decorator );
 
