@@ -77,9 +77,9 @@ int StackedTileLoader::tileRowCount( int level ) const
     return d->m_layerDecorator->tileRowCount( level );
 }
 
-GeoSceneAbstractTileProjection::Type StackedTileLoader::tileProjectionType() const
+const GeoSceneAbstractTileProjection *StackedTileLoader::tileProjection() const
 {
-    return d->m_layerDecorator->tileProjectionType();
+    return d->m_layerDecorator->tileProjection();
 }
 
 QSize StackedTileLoader::tileSize() const
@@ -198,7 +198,7 @@ void StackedTileLoader::updateTile( TileId const &tileId, QImage const &tileImag
         d->m_tilesOnDisplay.insert( stackedTileId, stackedTile );
 
         delete displayedTile;
-        displayedTile = 0;
+        displayedTile = nullptr;
 
         emit tileLoaded( stackedTileId );
     } else {
@@ -219,8 +219,6 @@ RenderState StackedTileLoader::renderState() const
 
 void StackedTileLoader::clear()
 {
-    mDebug() << Q_FUNC_INFO;
-
     qDeleteAll( d->m_tilesOnDisplay );
     d->m_tilesOnDisplay.clear();
     d->m_tileCache.clear(); // clear the tile cache in physical memory
