@@ -18,7 +18,6 @@
 
 #include "MarbleGlobal.h"
 #include "GeoDataDocument.h"
-#include "GeoPainter.h"
 
 #include <QString>
 #include <QImage>
@@ -27,6 +26,7 @@
 namespace Marble
 {
 
+class GeoPainter;
 class ViewportParams;
 
 class TextureColorizer
