@@ -177,7 +177,7 @@ qreal DarkenBlending::blendChannel( qreal const bottomColorIntensity,
 qreal DivideBlending::blendChannel( qreal const bottomColorIntensity,
                                     qreal const topColorIntensity ) const
 {
-    return log( 1.0  + bottomColorIntensity / ( 1.0  - topColorIntensity ) / 8.0) / log(2.0);
+    return log1p( bottomColorIntensity / ( 1.0  - topColorIntensity ) / 8.0) / log(2.0);
 }
 
 qreal GammaDarkBlending::blendChannel( qreal const bottomColorIntensity,
