@@ -46,7 +46,7 @@ QString MarbleDeclarativeObject::resolvePath(const QString &path) const
 bool MarbleDeclarativeObject::canExecute(const QString &program) const
 {
     QString path = QProcessEnvironment::systemEnvironment().value(QStringLiteral("PATH"), QStringLiteral("/usr/local/bin:/usr/bin:/bin"));
-    foreach( const QString &dir, path.split( QLatin1Char( ':' ) ) ) {
+    for( const QString &dir: path.split( QLatin1Char( ':' ) ) ) {
         QFileInfo const executable( QDir( dir ), program );
         if ( executable.exists() && executable.isExecutable() ) {
             return true;
