@@ -759,8 +759,13 @@ GeoDataCoordinates GeoDataCoordinates::rotateAround( const GeoDataCoordinates &a
     const Quaternion rotationAmount = Quaternion::fromEuler( 0, 0, unit == Radian ? angle : angle * DEG2RAD );
     const Quaternion resultAxis = quatAxis * rotationAmount * quatAxis.inverse();
 
+    return rotateAround(resultAxis);
+}
+
+GeoDataCoordinates GeoDataCoordinates::rotateAround(const Quaternion &rotAxis) const
+{
     Quaternion rotatedQuat = quaternion();
-    rotatedQuat.rotateAroundAxis(resultAxis);
+    rotatedQuat.rotateAroundAxis(rotAxis);
     qreal rotatedLon, rotatedLat;
     rotatedQuat.getSpherical(rotatedLon, rotatedLat);
     return GeoDataCoordinates(rotatedLon, rotatedLat, altitude());
@@ -807,6 +812,19 @@ GeoDataCoordinates GeoDataCoordinates::interpolate( const GeoDataCoordinates &ta
     return GeoDataCoordinates( lon, lat, alt );
 }
 
+GeoDataCoordinates GeoDataCoordinates::nlerp(const GeoDataCoordinates &target, double t) const
+{
+    qreal  lon = 0.0;
+    qreal  lat = 0.0;
+
+    const Quaternion itpos = Quaternion::nlerp(quaternion(), target.quaternion(), t);
+    itpos.getSpherical(lon, lat);
+
+    const qreal altitude = 0.5 * (d->m_altitude + target.altitude());
+
+    return GeoDataCoordinates(lon, lat, altitude);
+}
+
 GeoDataCoordinates GeoDataCoordinates::interpolate( const GeoDataCoordinates &before, const GeoDataCoordinates &target, const GeoDataCoordinates &after, double t_ ) const
 {
     double const t = qBound( 0.0, t_, 1.0 );
