@@ -158,59 +158,41 @@ qreal GeoDataLineStringPrivate::resolutionForLevel(int level)
     switch (level) {
         case 0:
             return 0.0655360;
-            break;
         case 1:
             return 0.0327680;
-            break;
         case 2:
             return 0.0163840;
-            break;
         case 3:
             return 0.0081920;
-            break;
         case 4:
             return 0.0040960;
-            break;
         case 5:
             return 0.0020480;
-            break;
         case 6:
             return 0.0010240;
-            break;
         case 7:
             return 0.0005120;
-            break;
         case 8:
             return 0.0002560;
-            break;
         case 9:
             return 0.0001280;
-            break;
         case 10:
             return 0.0000640;
-            break;
         case 11:
             return 0.0000320;
-            break;
         case 12:
             return 0.0000160;
-            break;
         case 13:
             return 0.0000080;
-            break;
         case 14:
             return 0.0000040;
-            break;
         case 15:
             return 0.0000020;
-            break;
         case 16:
             return 0.0000010;
-            break;
         default:
         case 17:
             return 0.0000005;
-            break;
     }
 }
 
@@ -742,14 +724,13 @@ void GeoDataLineStringPrivate::toDateLineCorrected(
     GeoDataLineString * dateLineCorrected = isClosed ? new GeoDataLinearRing( f )
                                                      : new GeoDataLineString( f );
 
-    qreal currentLon = 0.0;
     qreal previousLon = 0.0;
     int previousSign = 1;
 
     bool unfinished = false;
 
     for (; itPoint != itEndPoint; ++itPoint ) {
-        currentLon = itPoint->longitude();
+        const qreal currentLon = itPoint->longitude();
 
         int currentSign = ( currentLon < 0.0 ) ? -1 : +1 ;
 
