@@ -212,7 +212,7 @@ class GEODATA_EXPORT GeoDataPlacemark: public GeoDataFeature
         //OSM building
         Building,
 
-        // OpenStreetMap category Accomodation
+        // OpenStreetMap category Accommodation
         AccomodationCamping,
         AccomodationHostel,
         AccomodationHotel,
@@ -534,10 +534,10 @@ class GEODATA_EXPORT GeoDataPlacemark: public GeoDataFeature
     GeoDataVisualCategory visualCategory() const;
 
     /**
-     * Sets the symbol @p index of the placemark.
-     * @param  category  the new category to be used.
+     * Sets the symbol @p category of the placemark.
+     * @param index  the new category to be used.
      */
-    void setVisualCategory(GeoDataVisualCategory category);
+    void setVisualCategory(GeoDataVisualCategory index);
 
     /**
      * Return the coordinates of the placemark at time @p dateTime as a GeoDataCoordinates
@@ -552,7 +552,7 @@ class GEODATA_EXPORT GeoDataPlacemark: public GeoDataFeature
      *
      * @see GeoDataTrack::GeoDataTrack
      */
-    GeoDataCoordinates coordinate( const QDateTime &dateTime = QDateTime(), bool *iconAtCoordinates = 0 ) const;
+    GeoDataCoordinates coordinate( const QDateTime &dateTime = QDateTime(), bool *iconAtCoordinates = nullptr ) const;
 
     /**
      * The geometry of the GeoDataPlacemark is to be rendered to the marble map
