@@ -27,7 +27,7 @@ public:
 
     bool operator==( const GeoDataPlaylist &other ) const;
     bool operator!=( const GeoDataPlaylist &other ) const;
-    const char *nodeType() const;
+    const char *nodeType() const override;
 
     GeoDataTourPrimitive* primitive( int index );
     const GeoDataTourPrimitive* primitive( int index ) const;
