@@ -25,17 +25,12 @@ public:
     {
     }
 
-    virtual GeoDataGeometryPrivate* copy()
+    GeoDataGeometryPrivate *copy() const override
     { 
         GeoDataPointPrivate* copy = new  GeoDataPointPrivate;
         *copy = *this;
         return copy;
     }
-
-    virtual EnumGeometryId geometryId() const
-    {
-        return GeoDataPointId;
-    }
 };
 
 } // namespace Marble
