@@ -29,9 +29,11 @@ public:
 
     GeoDataPoint point() const;
 
-    virtual void paint(GeoPainter* painter, const ViewportParams *viewport, const QString &layer);
+    void paint(GeoPainter* painter, const ViewportParams *viewport, const QString &layer, int tileZoomLevel) override;
 
-    virtual const GeoDataLatLonAltBox& latLonAltBox() const;
+    const GeoDataLatLonAltBox& latLonAltBox() const override;
+
+    bool contains(const QPoint &point, const ViewportParams *viewport) const override;
 
 protected:
     GeoDataPoint m_point;
