@@ -32,7 +32,7 @@ namespace dgml
 class DgmlAvailableTagHandler : public GeoTagHandler
 {
  public:
-    virtual GeoNode* parse(GeoParser&) const;
+    GeoNode* parse(GeoParser&) const override;
 };
 
 }
