@@ -36,14 +36,14 @@ DGML_DEFINE_TAG_HANDLER(Head)
 
 GeoNode* DgmlHeadTagHandler::parse(GeoParser& parser) const
 {
-    Q_ASSERT(parser.isStartElement() && parser.isValidElement(dgmlTag_Head));
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(dgmlTag_Head)));
 
     // Checking for parent item
     GeoStackItem parentItem = parser.parentElement();
     if (parentItem.represents(dgmlTag_Document))
         return parentItem.nodeAs<GeoSceneDocument>()->head();
 
-    return 0;
+    return nullptr;
 }
 
 }
