@@ -32,7 +32,7 @@ namespace dgml
 class DgmlThemeTagHandler : public GeoTagHandler
 {
 public:
-    virtual GeoNode* parse(GeoParser&) const;
+    GeoNode* parse(GeoParser&) const override;
 };
 
 }
