@@ -25,7 +25,7 @@ KML_DEFINE_TAG_HANDLER( begin )
 
 GeoNode* KmlbeginTagHandler::parse( GeoParser& parser ) const
 {
-    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_begin ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_begin)));
 
     GeoStackItem parentItem = parser.parentElement();
 
@@ -35,7 +35,7 @@ GeoNode* KmlbeginTagHandler::parse( GeoParser& parser ) const
         parentItem.nodeAs<GeoDataTimeSpan>()->setBegin( beginStamp );
     }
 
-    return 0;
+    return nullptr;
 }
 
 }
