@@ -24,7 +24,7 @@ KML_DEFINE_TAG_HANDLER_GX22( LatLonQuad )
 
 GeoNode* KmlLatLonQuadTagHandler::parse( GeoParser& parser ) const
 {
-    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_LatLonQuad ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_LatLonQuad)));
     GeoStackItem parentItem = parser.parentElement();
     if( parentItem.represents( kmlTag_GroundOverlay ) )
     {
@@ -33,7 +33,7 @@ GeoNode* KmlLatLonQuadTagHandler::parse( GeoParser& parser ) const
         return quad;
     }
 
-    return 0;
+    return nullptr;
 }
 
 }
