@@ -20,7 +20,7 @@ namespace kml
 class KmlLookAtTagHandler : public GeoTagHandler
 {
 public:
-    virtual GeoNode * parse (GeoParser &) const;
+    GeoNode * parse (GeoParser &) const override;
 };
 
 }
