@@ -23,7 +23,7 @@ namespace kml
 class KmlOsmPlacemarkDataTagHandler : public GeoTagHandler
 {
 public:
-    virtual GeoNode* parse( GeoParser& parser ) const;
+    GeoNode* parse( GeoParser& parser ) const override;
 };
 
 }
