@@ -26,7 +26,7 @@ KML_DEFINE_TAG_HANDLER( rotation )
 
 GeoNode* KmlrotationTagHandler::parse( GeoParser& parser ) const
 {
-    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_rotation ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_rotation)));
 
     GeoStackItem parentItem = parser.parentElement();
 
@@ -48,7 +48,7 @@ GeoNode* KmlrotationTagHandler::parse( GeoParser& parser ) const
 
         parentItem.nodeAs<GeoDataPhotoOverlay>()->setRotation( rotation );
     }
-    return 0;
+    return nullptr;
 }
 
 }
