@@ -38,7 +38,7 @@ KML_DEFINE_TAG_HANDLER( Schema )
 
 GeoNode* KmlSchemaTagHandler::parse( GeoParser& parser ) const
 {
-    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_Schema ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_Schema)));
 
     GeoStackItem parentItem = parser.parentElement();
 
@@ -51,7 +51,7 @@ GeoNode* KmlSchemaTagHandler::parse( GeoParser& parser ) const
         parentItem.nodeAs<GeoDataDocument>()->addSchema( schema );
         return &parentItem.nodeAs<GeoDataDocument>()->schema( schema.id() );
     }
-    return 0;
+    return nullptr;
 
 }
 
