@@ -38,7 +38,7 @@ KML_DEFINE_TAG_HANDLER( Style )
 
 GeoNode* KmlStyleTagHandler::parse( GeoParser& parser ) const
 {
-    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_Style ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_Style)));
 
 
     GeoStackItem parentItem = parser.parentElement();
@@ -56,7 +56,7 @@ GeoNode* KmlStyleTagHandler::parse( GeoParser& parser ) const
         return style.data();
     }
     // FIXME: KMLStyle can be contained in MultiGeometry as well
-    return 0;
+    return nullptr;
 }
 
 }
