@@ -28,7 +28,7 @@ KML_DEFINE_TAG_HANDLER_GX22( value )
 
 GeoNode* KmlvalueTagHandler::parse( GeoParser& parser ) const
 {
-    Q_ASSERT( parser.isStartElement() && parser.isValidElement( kmlTag_value ) );
+    Q_ASSERT(parser.isStartElement() && parser.isValidElement(QLatin1String(kmlTag_value)));
 
     GeoStackItem parentItem = parser.parentElement();
 
@@ -39,7 +39,7 @@ GeoNode* KmlvalueTagHandler::parse( GeoParser& parser ) const
         QString value = parser.readElementText().trimmed();
         parentItem.nodeAs<GeoDataSimpleArrayData>()->append( QVariant( value ) );
     }
-    return 0;
+    return nullptr;
 }
 
 }
