@@ -21,6 +21,8 @@
 
 #include "GeoSceneIcon.h"
 
+#include "GeoSceneTypes.h"
+
 namespace Marble
 {
 
@@ -53,4 +55,9 @@ void GeoSceneIcon::setColor( const QColor& color )
     m_color = color;
 }
 
+const char *GeoSceneIcon::nodeType() const
+{
+    return GeoSceneTypes::GeoSceneIconType;
+}
+
 }
