@@ -19,7 +19,7 @@ namespace Marble
 class DgmlSectionTagWriter : public GeoTagWriter
 {
 public:
-    virtual bool write( const GeoNode *node, GeoWriter& writer ) const;    
+    bool write( const GeoNode *node, GeoWriter& writer ) const override;    
 };
 
 }
