@@ -21,7 +21,7 @@ namespace Marble
 class KmlListStyleTagWriter : public GeoTagWriter
 {
 public:
-    virtual bool write( const GeoNode *node, GeoWriter& writer ) const;
+    bool write( const GeoNode *node, GeoWriter& writer ) const override;
 
 private:
     static QString itemTypeToString( GeoDataListStyle::ListItemType itemType );
