@@ -15,7 +15,6 @@
 #include "GeoDataSchemaData.h"
 #include "GeoDataExtendedData.h"
 #include "GeoDataFeature.h"
-#include "GeoDataTypes.h"
 #include "GeoDataLinearRing.h"
 #include "GeoDataPolygon.h"
 #include "GeoWriter.h"
@@ -28,17 +27,22 @@ namespace Marble
 bool KmlOsmPlacemarkDataTagWriter::write( const GeoDataFeature *feature,
                                           GeoWriter& writer )
 {
-    if ( feature->nodeType() != GeoDataTypes::GeoDataPlacemarkType ) {
+    const GeoDataPlacemark *placemark = geodata_cast<GeoDataPlacemark>(feature);
+
+    if (!placemark) {
         return false;
     }
-    const GeoDataPlacemark *placemark = static_cast<const GeoDataPlacemark*>( feature );
+
+    const OsmPlacemarkData &osmData = placemark->osmData();
+    if (osmData.isNull()) {
+        return true;
+    }
 
     writer.writeStartElement( kml::kmlTag_ExtendedData );
 
     // We declare the "mx" namespace for the custom osmPlacemarkData XML schema
     writer.writeNamespace( kml::kmlTag_nameSpaceMx, "mx" );
 
-    const OsmPlacemarkData &osmData = placemark->osmData();
     KmlOsmPlacemarkDataTagWriter::writeOsmData( placemark->geometry(), osmData, writer );
 
     writer.writeEndElement();
@@ -73,12 +77,10 @@ bool KmlOsmPlacemarkDataTagWriter::writeOsmData( const GeoDataGeometry *geometry
     if ( geometry ) {
 
         // Ways
-        if ( geometry->nodeType() == GeoDataTypes::GeoDataLineStringType ||
-             geometry->nodeType() == GeoDataTypes::GeoDataLinearRingType ) {
+        if (const GeoDataLineString *lineString = dynamic_cast<const GeoDataLineString *>(geometry)) {
             int ndIndex = 0;
 
             // Writing the component nodes
-            const GeoDataLineString *lineString = static_cast<const GeoDataLineString*>( geometry );
             QVector<GeoDataCoordinates>::const_iterator nodeIt = lineString->begin();
             QVector<GeoDataCoordinates>::const_iterator nodeEnd = lineString->end();
             for ( ; nodeIt != nodeEnd; ++nodeIt ) {
@@ -90,11 +92,10 @@ bool KmlOsmPlacemarkDataTagWriter::writeOsmData( const GeoDataGeometry *geometry
             }
         }
         // Polygons
-        else if ( geometry->nodeType() == GeoDataTypes::GeoDataPolygonType ) {
+        else if (const GeoDataPolygon *polygon = geodata_cast<GeoDataPolygon>(geometry)) {
             int memberIndex = -1;
 
             // Writing the outerBoundary osmData
-            const GeoDataPolygon *polygon = static_cast<const GeoDataPolygon*>( geometry );
             const GeoDataLinearRing &outerRing = polygon->outerBoundary();
             const OsmPlacemarkData &outerRingOsmData = osmData.memberReference( memberIndex );
             writer.writeStartElement( kml::kmlTag_nameSpaceMx, kml::kmlTag_member );
@@ -103,7 +104,7 @@ bool KmlOsmPlacemarkDataTagWriter::writeOsmData( const GeoDataGeometry *geometry
             writer.writeEndElement();
 
             // Writing the innerBoundaries
-            foreach ( const GeoDataLinearRing &innerRing, polygon->innerBoundaries() ) {
+            for ( const GeoDataLinearRing &innerRing: polygon->innerBoundaries() ) {
                 const OsmPlacemarkData &innerRingOsmData = osmData.memberReference( ++memberIndex );
                 writer.writeStartElement( kml::kmlTag_nameSpaceMx, kml::kmlTag_member );
                 writer.writeAttribute( "index", QString::number( memberIndex ) );
