@@ -8,9 +8,10 @@
 // Copyright 2014 Abhinav Gangwar <abhgang@gmail.com>
 //
 
+#include "KmlSchemaDataTagWriter.h"
+
 #include <QString>
 
-#include "KmlSchemaDataTagWriter.h"
 #include "KmlElementDictionary.h"
 
 #include "GeoWriter.h"
@@ -35,7 +36,7 @@ bool KmlSchemaDataTagWriter::write( const GeoNode *node, GeoWriter& writer ) con
     QString schemaUrl = schemaData->schemaUrl();
     writer.writeAttribute( "schemaUrl", schemaUrl );
 
-    foreach( const GeoDataSimpleData& data, schemaData->simpleDataList() ) {
+    for( const GeoDataSimpleData& data: schemaData->simpleDataList() ) {
         writeElement( &data, writer );
     }
     writer.writeEndElement();
