@@ -21,7 +21,7 @@ namespace Marble
 {
 static GeoTagWriterRegistrar s_writerLookAt(
         GeoTagWriter::QualifiedName( GeoDataTypes::GeoDataScreenOverlayType,
-                                     kml::kmlTag_nameSpace22 ),
+                                     kml::kmlTag_nameSpaceOgc22 ),
         new KmlScreenOverlayWriter );
 
 KmlScreenOverlayWriter::KmlScreenOverlayWriter() : KmlOverlayTagWriter( kml::kmlTag_ScreenOverlay )
@@ -36,15 +36,15 @@ bool KmlScreenOverlayWriter::writeMid( const GeoNode *node, GeoWriter& writer )
 
     const GeoDataScreenOverlay *screenOverlay = static_cast<const GeoDataScreenOverlay*>( node );
     writeVec2( kml::kmlTag_overlayXY, screenOverlay->overlayXY(), writer );
-    writeVec2( kml::kmlTag_rotationXY, screenOverlay->rotationXY(), writer );
     writeVec2( kml::kmlTag_screenXY, screenOverlay->screenXY(), writer );
+    writeVec2( kml::kmlTag_rotationXY, screenOverlay->rotationXY(), writer );
     writeVec2( kml::kmlTag_size, screenOverlay->size(), writer );
     QString const rotation = QString::number(screenOverlay->rotation());
     writer.writeOptionalElement( kml::kmlTag_rotation, rotation, "0" );
     return true;
 }
 
-void KmlScreenOverlayWriter::writeVec2( const QString &element, const GeoDataVec2 &vec2, GeoWriter &writer ) const
+void KmlScreenOverlayWriter::writeVec2( const QString &element, const GeoDataVec2 &vec2, GeoWriter &writer )
 {
     writer.writeStartElement( element );
     writer.writeAttribute( "x", QString::number( vec2.x() ) );
@@ -54,7 +54,7 @@ void KmlScreenOverlayWriter::writeVec2( const QString &element, const GeoDataVec
     writer.writeEndElement();
 }
 
-QString KmlScreenOverlayWriter::unitToString( GeoDataVec2::Unit unit ) const
+QString KmlScreenOverlayWriter::unitToString( GeoDataVec2::Unit unit )
 {
     switch( unit ) {
     case GeoDataVec2::Fraction:    return "fraction";
