@@ -21,8 +21,8 @@ namespace Marble
 
 class KmlSimpleFieldTagWriter : public GeoTagWriter
 {
-  public:
-    virtual bool write( const GeoNode *node, GeoWriter& writer ) const;
+public:
+    bool write( const GeoNode *node, GeoWriter& writer ) const override;
 
 private:
     static QString resolveType( GeoDataSimpleField::SimpleFieldType type );
