@@ -19,7 +19,7 @@ class KmlTrackWriter : public GeoTagWriter
 {
 
 public:
-    virtual bool write( const GeoNode *node, GeoWriter &writer ) const;
+    bool write( const GeoNode *node, GeoWriter &writer ) const override;
 };
 
 }
