@@ -27,8 +27,8 @@ ScreenGraphicsItem::ScreenGraphicsItem( MarbleGraphicsItem *parent )
 {
 }
 
-ScreenGraphicsItem::ScreenGraphicsItem( ScreenGraphicsItemPrivate *d_ptr )
-    : MarbleGraphicsItem( d_ptr )
+ScreenGraphicsItem::ScreenGraphicsItem(ScreenGraphicsItemPrivate *dd)
+    : MarbleGraphicsItem(dd)
 {
 }
 
@@ -38,32 +38,38 @@ ScreenGraphicsItem::~ScreenGraphicsItem()
 
 QPointF ScreenGraphicsItem::position() const
 {
-    return p()->m_position;
+    Q_D(const ScreenGraphicsItem);
+    return d->m_position;
 }
 
 void ScreenGraphicsItem::setPosition( const QPointF& position )
 {
-    p()->m_position = position;
+    Q_D(ScreenGraphicsItem);
+    d->m_position = position;
 }
 
 QPointF ScreenGraphicsItem::positivePosition() const
 {
-    return p()->positivePosition();
+    Q_D(const ScreenGraphicsItem);
+    return d->positivePosition();
 }
 
-QList<QPointF> ScreenGraphicsItem::absolutePositions() const
+QVector<QPointF> ScreenGraphicsItem::absolutePositions() const
 {
-    return p()->absolutePositions();
+    Q_D(const ScreenGraphicsItem);
+    return d->absolutePositions();
 }
 
 ScreenGraphicsItem::GraphicsItemFlags ScreenGraphicsItem::flags() const
 {
-    return p()->m_flags;
+    Q_D(const ScreenGraphicsItem);
+    return d->m_flags;
 }
 
 void ScreenGraphicsItem::setFlags( ScreenGraphicsItem::GraphicsItemFlags flags )
 {
-    p()->m_flags = flags;
+    Q_D(ScreenGraphicsItem);
+    d->m_flags = flags;
 }
 
 bool ScreenGraphicsItem::eventFilter( QObject *object, QEvent *e )
@@ -72,13 +78,14 @@ bool ScreenGraphicsItem::eventFilter( QObject *object, QEvent *e )
     if ( !widget ) {
         return MarbleGraphicsItem::eventFilter( object, e );
     }
-    
-    if ( !p()->m_floatItemMoving ) {
+
+    Q_D(ScreenGraphicsItem);
+    if (!d->m_floatItemMoving) {
         if ( MarbleGraphicsItem::eventFilter( object, e ) ) {
             return true;
         }
-    
-        if ( !visible() || !p()->isMovable() ) {
+
+        if (!visible() || !d->isMovable()) {
             return false;
         }
         
@@ -94,8 +101,8 @@ bool ScreenGraphicsItem::eventFilter( QObject *object, QEvent *e )
             // Click and move above a float item triggers moving the float item
             if ( contains( event->pos() ) ) {
                 if ( event->button() == Qt::LeftButton ) {
-                    p()->m_floatItemMoveStartPos = event->pos();
-                    p()->m_floatItemMoving = true;
+                    d->m_floatItemMoveStartPos = event->pos();
+                    d->m_floatItemMoving = true;
                     return true;
                 }
             }
@@ -118,22 +125,22 @@ bool ScreenGraphicsItem::eventFilter( QObject *object, QEvent *e )
             if ( e->type() == QEvent::MouseMove && event->buttons() & Qt::LeftButton ) {
                     const QPoint &point = event->pos();
                     QPointF position = positivePosition();
-                    qreal newX = qMax<qreal>( 0, position.x()+point.x()-p()->m_floatItemMoveStartPos.x() );
-                    qreal newY = qMax<qreal>( 0, position.y()+point.y()-p()->m_floatItemMoveStartPos.y() );
+                    qreal newX = qMax<qreal>(0, position.x() + point.x() - d->m_floatItemMoveStartPos.x());
+                    qreal newY = qMax<qreal>(0, position.y() + point.y() - d->m_floatItemMoveStartPos.y());
 
                     // docking behavior
                     const qreal dockArea = 60.0; // Alignment area width/height
                     const qreal dockJump = 30.0; // Alignment indicator jump size
                     if ( widget->width()-size().width()-newX < dockArea ) {
                         newX = qMin( qreal( -1.0 ), size().width() + newX-widget->width() );
-                        if ( p()->m_floatItemMoveStartPos.x() < event->pos().x() ) {
+                        if (d->m_floatItemMoveStartPos.x() < event->pos().x()) {
                             // Indicate change to right alignment with a short jump
                             newX = qMax( newX, -(dockArea-dockJump) );
                         }
                     }
                     if ( widget->height()-size().height()-newY < dockArea ) {
                         newY = qMin( qreal( -1.0 ), size().height() + newY-widget->height() );
-                        if (p()->m_floatItemMoveStartPos.y()<event->pos().y()) {
+                        if (d->m_floatItemMoveStartPos.y() < event->pos().y()) {
                         // Indicate change to bottom alignment with a short jump
                         newY = qMax( newY, -( dockArea - dockJump ) );
                         }
@@ -144,7 +151,7 @@ bool ScreenGraphicsItem::eventFilter( QObject *object, QEvent *e )
                     // antialiasing could result into painting on these pixels to.
                     QRect newFloatItemRect = QRectF( positivePosition() - QPoint( 1, 1 ),
                                                      size() + QSize( 2, 2 ) ).toRect();
-                    p()->m_floatItemMoveStartPos = event->pos();
+                    d->m_floatItemMoveStartPos = event->pos();
                     QRegion dirtyRegion( floatItemRect.toRect() );
                     dirtyRegion = dirtyRegion.united( newFloatItemRect );
 
@@ -155,11 +162,11 @@ bool ScreenGraphicsItem::eventFilter( QObject *object, QEvent *e )
             }
 
             if ( e->type() == QEvent::MouseButtonRelease ) {
-                p()->m_floatItemMoving = false;
+                d->m_floatItemMoving = false;
             }
 
             // Use a special cursor as long as the item is moved
-            if ( p()->m_floatItemMoving ) {
+            if (d->m_floatItemMoving) {
                 widget->setCursor(QCursor(Qt::SizeAllCursor));
                 return true;
             }
@@ -168,13 +175,3 @@ bool ScreenGraphicsItem::eventFilter( QObject *object, QEvent *e )
         return MarbleGraphicsItem::eventFilter( object, e );
     }
 }
-
-ScreenGraphicsItemPrivate *ScreenGraphicsItem::p()
-{
-    return static_cast<ScreenGraphicsItemPrivate *>( d );
-}
-
-const ScreenGraphicsItemPrivate *ScreenGraphicsItem::p() const
-{
-    return static_cast<const ScreenGraphicsItemPrivate *>( d );
-}
