@@ -24,23 +24,23 @@ class GroundLayer : public LayerInterface
 
     GroundLayer();
 
-    ~GroundLayer();
+    ~GroundLayer() override;
 
-    virtual QStringList renderPosition() const;
+    QStringList renderPosition() const override;
 
-    virtual bool render( GeoPainter *painter, ViewportParams *viewport,
+    bool render( GeoPainter *painter, ViewportParams *viewport,
                          const QString& renderPos = QLatin1String("NONE"),
-                         GeoSceneLayer * layer = 0 );
+                         GeoSceneLayer * layer = nullptr ) override;
 
-    virtual qreal zValue() const;
+    qreal zValue() const override;
 
     void setColor( const QColor &color );
 
     QColor color() const;
 
-    RenderState renderState() const;
+    RenderState renderState() const override;
 
-    virtual QString runtimeTrace() const { return QStringLiteral("GroundLayer"); }
+    QString runtimeTrace() const override { return QStringLiteral("GroundLayer"); }
 
  private:
     QColor m_color;  // Gets the color specified via DGML's <map bgcolor="">
