@@ -25,6 +25,7 @@
 #include "GeoDataGroundOverlay.h"
 #include "GeoPainter.h"
 #include "GeoSceneGroup.h"
+#include "GeoSceneTextureTileDataset.h"
 #include "GeoSceneTypes.h"
 #include "MergedLayerDecorator.h"
 #include "MarbleDebug.h"
@@ -97,9 +98,9 @@ TextureLayer::Private::Private( HttpDownloadManager *downloadManager,
     , m_tileLoader( &m_layerDecorator )
     , m_centerCoordinates()
     , m_tileZoomLevel( -1 )
-    , m_texmapper( 0 )
-    , m_texcolorizer( 0 )
-    , m_textureLayerSettings( 0 )
+    , m_texmapper( nullptr )
+    , m_texcolorizer( nullptr )
+    , m_textureLayerSettings( nullptr )
     , m_repaintTimer()
 {
     m_groundOverlayModel.setSourceModel( groundOverlayModel );
@@ -137,7 +138,7 @@ void TextureLayer::Private::updateTextureLayers()
 {
     QVector<GeoSceneTextureTileDataset const *> result;
 
-    foreach ( const GeoSceneTextureTileDataset *candidate, m_textures ) {
+    for ( const GeoSceneTextureTileDataset *candidate: m_textures ) {
         bool enabled = true;
         if ( m_textureLayerSettings ) {
             const bool propertyExists = m_textureLayerSettings->propertyValue( candidate->name(), enabled );
@@ -185,7 +186,7 @@ void TextureLayer::Private::addGroundOverlays( const QModelIndex& parent, int fi
             continue;
         }
 
-        int pos = qLowerBound( m_groundOverlayCache.begin(), m_groundOverlayCache.end(), overlay, drawOrderLessThan ) - m_groundOverlayCache.begin();
+        int pos = std::lower_bound( m_groundOverlayCache.begin(), m_groundOverlayCache.end(), overlay, drawOrderLessThan ) - m_groundOverlayCache.begin();
         m_groundOverlayCache.insert( pos, overlay );
     }
 
@@ -200,7 +201,7 @@ void TextureLayer::Private::removeGroundOverlays( const QModelIndex& parent, int
         QModelIndex index = m_groundOverlayModel.index( i, 0, parent );
         const GeoDataGroundOverlay *overlay = static_cast<GeoDataGroundOverlay *>( qvariant_cast<GeoDataObject *>( index.data( MarblePlacemarkModel::ObjectPointerRole ) ) );
 
-        int pos = qLowerBound( m_groundOverlayCache.begin(), m_groundOverlayCache.end(), overlay, drawOrderLessThan ) - m_groundOverlayCache.begin();
+        int pos = std::lower_bound( m_groundOverlayCache.begin(), m_groundOverlayCache.end(), overlay, drawOrderLessThan ) - m_groundOverlayCache.begin();
         if (pos >= 0 && pos < m_groundOverlayCache.size() ) {
             m_groundOverlayCache.removeAt( pos );
         }
@@ -233,7 +234,7 @@ void TextureLayer::Private::updateGroundOverlays()
 void TextureLayer::Private::addCustomTextures()
 {
     m_textures.reserve(m_textures.size() + m_customTextures.size());
-    foreach (GeoSceneTextureTileDataset *t, m_customTextures)
+    for (GeoSceneTextureTileDataset *t: m_customTextures)
     {
         m_textures.append(t);
     }
@@ -426,7 +427,7 @@ void TextureLayer::setProjection( Projection projection )
             d->m_texmapper = new GenericScanlineTextureMapper( &d->m_tileLoader );
             break;
         default:
-            d->m_texmapper = 0;
+            d->m_texmapper = nullptr;
     }
     Q_ASSERT( d->m_texmapper );
 }
@@ -447,15 +448,13 @@ void TextureLayer::setVolatileCacheLimit( quint64 kilobytes )
 
 void TextureLayer::reset()
 {
-    mDebug() << Q_FUNC_INFO;
-
     d->m_tileLoader.clear();
     setNeedsUpdate();
 }
 
 void TextureLayer::reload()
 {
-    foreach ( const TileId &id, d->m_tileLoader.visibleTiles() ) {
+    for ( const TileId &id: d->m_tileLoader.visibleTiles() ) {
         // it's debatable here, whether DownloadBulk or DownloadBrowse should be used
         // but since "reload" or "refresh" seems to be a common action of a browser and it
         // allows for more connections (in our model), use "DownloadBrowse"
@@ -471,7 +470,7 @@ void TextureLayer::downloadStackedTile( const TileId &stackedTileId )
 void TextureLayer::setMapTheme( const QVector<const GeoSceneTextureTileDataset *> &textures, const GeoSceneGroup *textureLayerSettings, const QString &seaFile, const QString &landFile )
 {
     delete d->m_texcolorizer;
-    d->m_texcolorizer = 0;
+    d->m_texcolorizer = nullptr;
 
     if ( QFileInfo( seaFile ).isReadable() || QFileInfo( landFile ).isReadable() ) {
         d->m_texcolorizer = new TextureColorizer( seaFile, landFile );
@@ -499,9 +498,9 @@ QSize TextureLayer::tileSize() const
     return d->m_layerDecorator.tileSize();
 }
 
-GeoSceneAbstractTileProjection::Type TextureLayer::tileProjectionType() const
+const GeoSceneAbstractTileProjection *TextureLayer::tileProjection() const
 {
-    return d->m_layerDecorator.tileProjectionType();
+    return d->m_layerDecorator.tileProjection();
 }
 
 int TextureLayer::tileColumnCount( int level ) const
@@ -514,7 +513,7 @@ int TextureLayer::tileRowCount( int level ) const
     return d->m_layerDecorator.tileRowCount( level );
 }
 
-qint64 TextureLayer::volatileCacheLimit() const
+quint64 TextureLayer::volatileCacheLimit() const
 {
     return d->m_tileLoader.volatileCacheLimit();
 }
