@@ -24,8 +24,8 @@ class EditGroundOverlayDialog : public QDialog
     Q_OBJECT
 
 public:
-    EditGroundOverlayDialog( GeoDataGroundOverlay *overlay, TextureLayer *textureLayer, QWidget *parent = 0 );
-    ~EditGroundOverlayDialog();
+    EditGroundOverlayDialog( GeoDataGroundOverlay *overlay, TextureLayer *textureLayer, QWidget *parent = nullptr );
+    ~EditGroundOverlayDialog() override;
 
 private Q_SLOTS:
     void updateGroundOverlay();
