@@ -20,17 +20,17 @@
 namespace Marble {
 
 EarthquakePlugin::EarthquakePlugin()
-    : AbstractDataPlugin( 0 ),
-      m_ui( 0 ),
-      m_configDialog( 0 ),
+    : AbstractDataPlugin( nullptr ),
+      m_ui( nullptr ),
+      m_configDialog( nullptr ),
       m_maximumNumberOfItems( 100 )
 {
 }
 
 EarthquakePlugin::EarthquakePlugin( const MarbleModel *marbleModel )
     : AbstractDataPlugin( marbleModel ),
-      m_ui( 0 ),
-      m_configDialog( 0 ),
+      m_ui( nullptr ),
+      m_configDialog( nullptr ),
       m_minMagnitude( 0.0 ),
       m_startDate( QDateTime::fromString( "2006-02-04", "yyyy-MM-dd" ) ),
       m_endDate( marbleModel->clockDateTime() ),
@@ -66,12 +66,12 @@ QString EarthquakePlugin::guiString() const
 
 QString EarthquakePlugin::nameId() const
 {
-    return "earthquake";
+    return QStringLiteral("earthquake");
 }
 
 QString EarthquakePlugin::version() const
 {
-    return "1.0";
+    return QStringLiteral("1.0");
 }
 
 QString EarthquakePlugin::description() const
@@ -81,19 +81,19 @@ QString EarthquakePlugin::description() const
 
 QString EarthquakePlugin::copyrightYears() const
 {
-    return "2010, 2011";
+    return QStringLiteral("2010, 2011");
 }
 
-QList<PluginAuthor> EarthquakePlugin::pluginAuthors() const
+QVector<PluginAuthor> EarthquakePlugin::pluginAuthors() const
 {
-    return QList<PluginAuthor>()
-            << PluginAuthor( QString::fromUtf8( "Utku Aydın" ), "utkuaydin34@gmail.com" )
-            << PluginAuthor( QString::fromUtf8( "Daniel Marth" ), "danielmarth@gmx.at" );
+    return QVector<PluginAuthor>()
+            << PluginAuthor(QStringLiteral("Utku Aydın"), QStringLiteral("utkuaydin34@gmail.com"))
+            << PluginAuthor(QStringLiteral("Daniel Marth"), QStringLiteral("danielmarth@gmx.at"));
 }
 
 QIcon EarthquakePlugin::icon() const
 {
-    return QIcon(":/icons/earthquake.png");
+    return QIcon(QStringLiteral(":/icons/earthquake.png"));
 }
 
 QDialog *EarthquakePlugin::configDialog()
@@ -128,13 +128,13 @@ QHash<QString,QVariant> EarthquakePlugin::settings() const
 {
     QHash<QString, QVariant> settings = AbstractDataPlugin::settings();
 
-    settings.insert( "numResults", m_numResults );
-    settings.insert( "minMagnitude", m_minMagnitude );
-    settings.insert( "startDate", m_startDate );
-    settings.insert( "endDate", m_endDate );
-    settings.insert( "pastDays", m_pastDays );
-    settings.insert( "timeRangeNPastDays", m_timeRangeNPastDays );
-    settings.insert( "maximumNumberOfItems", m_maximumNumberOfItems );
+    settings.insert(QStringLiteral("numResults"), m_numResults);
+    settings.insert(QStringLiteral("minMagnitude"), m_minMagnitude);
+    settings.insert(QStringLiteral("startDate"), m_startDate);
+    settings.insert(QStringLiteral("endDate"), m_endDate);
+    settings.insert(QStringLiteral("pastDays"), m_pastDays);
+    settings.insert(QStringLiteral("timeRangeNPastDays"), m_timeRangeNPastDays);
+    settings.insert(QStringLiteral("maximumNumberOfItems"), m_maximumNumberOfItems);
 
     return settings;
 }
@@ -143,13 +143,13 @@ void EarthquakePlugin::setSettings( const QHash<QString,QVariant> &settings )
 {
     AbstractDataPlugin::setSettings( settings );
 
-    m_numResults = settings.value( "numResults", 20 ).toInt();
-    m_minMagnitude = settings.value( "minMagnitude", 0.0 ).toReal();
-    m_startDate = settings.value( "startDate", QDateTime::fromString( "2006-02-04", "yyyy-MM-dd" ) ).toDateTime();
-    m_endDate = settings.value( "endDate", marbleModel()->clockDateTime() ).toDateTime();
-    m_pastDays = settings.value( "pastDays", 30 ).toInt();
-    m_timeRangeNPastDays = settings.value( "timeRangeNPastDays", true ).toBool();
-    m_maximumNumberOfItems = settings.value( "maximumNumberOfItems", m_maximumNumberOfItems ).toInt();
+    m_numResults = settings.value(QStringLiteral("numResults"), 20).toInt();
+    m_minMagnitude = settings.value(QStringLiteral("minMagnitude"), 0.0).toReal();
+    m_startDate = settings.value(QStringLiteral("startDate"), QDateTime::fromString(QStringLiteral("2006-02-04"), QStringLiteral("yyyy-MM-dd"))).toDateTime();
+    m_endDate = settings.value(QStringLiteral("endDate"), marbleModel()->clockDateTime()).toDateTime();
+    m_pastDays = settings.value(QStringLiteral("pastDays"), 30).toInt();
+    m_timeRangeNPastDays = settings.value(QStringLiteral("timeRangeNPastDays"), true).toBool();
+    m_maximumNumberOfItems = settings.value(QStringLiteral("maximumNumberOfItems"), m_maximumNumberOfItems).toInt();
     
     emit settingsChanged( nameId() );
 }
