@@ -21,8 +21,8 @@ class MeasureConfigDialog : public QDialog
     Q_OBJECT
 
 public:
-    explicit MeasureConfigDialog(QDialog *parent = 0);
-    ~MeasureConfigDialog();
+    explicit MeasureConfigDialog(QDialog *parent = nullptr);
+    ~MeasureConfigDialog() override;
 
     bool showBearingLabel() const;
     bool showBearingLabelChange() const;
