@@ -46,7 +46,7 @@ PhotoPluginItem::PhotoPluginItem( MarbleWidget *widget, QObject *parent )
     : AbstractDataPluginItem( parent ),
       m_marbleWidget( widget ),
       m_image( this ),
-      m_browser( 0 )
+      m_browser( nullptr )
 {
     m_action = new QAction( this );
     connect( m_action, SIGNAL(triggered()), this, SLOT(openBrowser()) );
