@@ -26,23 +26,23 @@ class PostalCodePlugin : public AbstractDataPlugin {
 
     explicit PostalCodePlugin( const MarbleModel *marbleModel );
 
-    virtual void initialize();
+    void initialize() override;
 
-    QString name() const;
+    QString name() const override;
 
-    QString guiString() const;
+    QString guiString() const override;
 
-    QString nameId() const;
+    QString nameId() const override;
 
-    QString version() const;
+    QString version() const override;
 
-    QString description() const;
+    QString description() const override;
 
-    QString copyrightYears() const;
+    QString copyrightYears() const override;
 
     QVector<PluginAuthor> pluginAuthors() const override;
 
-    QIcon icon() const;
+    QIcon icon() const override;
 };
 
 }
