@@ -18,9 +18,9 @@
 
 #include <QUrl>
 #include <QDateTime>
-#include <QScriptEngine>
-#include <QScriptValue>
-#include <QScriptValueIterator>
+#include <QJsonDocument>
+#include <QJsonArray>
+#include <QJsonObject>
 
 #include <QUrlQuery>
 
@@ -44,7 +44,7 @@ GeoNamesWeatherService::~GeoNamesWeatherService()
 void GeoNamesWeatherService::getAdditionalItems( const GeoDataLatLonAltBox& box,
                                             qint32 number )
 {
-    if( marbleModel()->planetId() != "earth" ) {
+    if (marbleModel()->planetId() != QLatin1String("earth")) {
         return;
     }
 
@@ -63,7 +63,7 @@ void GeoNamesWeatherService::getAdditionalItems( const GeoDataLatLonAltBox& box,
 
 void GeoNamesWeatherService::getItem( const QString &id )
 {
-    if( marbleModel()->planetId() != "earth" ) {
+    if (marbleModel()->planetId() != QLatin1String("earth")) {
         return;
     }
 
@@ -79,26 +79,26 @@ void GeoNamesWeatherService::getItem( const QString &id )
 
 void GeoNamesWeatherService::parseFile( const QByteArray& file )
 {
-    QScriptValue data;
-    QScriptEngine engine;
-
-    // Qt requires parentheses around json code
-    data = engine.evaluate( '(' + QString( file ) + ')' );
+    QJsonDocument jsonDoc = QJsonDocument::fromJson(file);
+    QJsonValue weatherObservationsValue = jsonDoc.object().value(QStringLiteral("weatherObservations"));
 
     // Parse if any result exists
     QList<AbstractDataPluginItem*> items;
-    if ( data.property( "weatherObservations" ).isArray() ) {
-        QScriptValueIterator iterator( data.property( "weatherObservations" ) );
+    if (weatherObservationsValue.isArray()) {
         // Add items to the list
-        while ( iterator.hasNext() ) {
-            iterator.next();
-            AbstractDataPluginItem* item = parse( iterator.value() );
+        QJsonArray weatherObservationsArray = weatherObservationsValue.toArray();
+        for (int index = 0; index < weatherObservationsArray.size(); ++index) {
+            QJsonObject weatherObservationObject = weatherObservationsArray[index].toObject();
+
+            AbstractDataPluginItem* item = parse(weatherObservationObject);
             if ( item ) {
                 items << item;
             }
         }
     } else {
-        AbstractDataPluginItem* item = parse( data.property( "weatherObservation" ) );
+        QJsonValue weatherObservationValue = jsonDoc.object().value(QStringLiteral("weatherObservation"));
+        QJsonObject weatherObservationObject = weatherObservationValue.toObject();
+        AbstractDataPluginItem* item = parse(weatherObservationObject);
         if ( item ) {
             items << item;
         }
@@ -107,27 +107,27 @@ void GeoNamesWeatherService::parseFile( const QByteArray& file )
     emit createdItems( items );
 }
 
-AbstractDataPluginItem *GeoNamesWeatherService::parse( const QScriptValue &value )
+AbstractDataPluginItem *GeoNamesWeatherService::parse(const QJsonObject &weatherObservationObject)
 {
-    QString condition = value.property( "weatherCondition" ).toString();
-    QString clouds = value.property( "clouds" ).toString();
-    int windDirection = value.property( "windDirection" ).toInteger();
-    QString id = value.property( "ICAO" ).toString();
-    int temperature = value.property( "temperature" ).toInteger();
-    int windSpeed = value.property( "windSpeed" ).toInteger();
-    int humidity = value.property( "humidity" ).toInteger();
-    double pressure = value.property( "seaLevelPressure" ).toNumber();
-    QString name = value.property( "stationName" ).toString();
-    QDateTime date = QDateTime::fromString(
-                value.property( "datetime" ).toString(), "yyyy-MM-dd hh:mm:ss" );
-    double longitude = value.property( "lng" ).toNumber();
-    double latitude = value.property( "lat" ).toNumber();
+    const QString condition = weatherObservationObject.value(QStringLiteral("weatherCondition")).toString();
+    const QString clouds = weatherObservationObject.value(QStringLiteral("clouds")).toString();
+    const int windDirection = weatherObservationObject.value(QStringLiteral("windDirection")).toInt();
+    QString id = weatherObservationObject.value(QStringLiteral("ICAO")).toString();
+    const double temperature = weatherObservationObject.value(QStringLiteral("temperature")).toString().toDouble(); //delivered as string
+    const int windSpeed = weatherObservationObject.value(QStringLiteral("windSpeed")).toString().toInt(); //delivered as string
+    const int humidity = weatherObservationObject.value(QStringLiteral("humidity")).toInt();
+    const double pressure = weatherObservationObject.value(QStringLiteral("seaLevelPressure")).toDouble();
+    const QString name = weatherObservationObject.value(QStringLiteral("stationName")).toString();
+    const QDateTime date = QDateTime::fromString(
+                weatherObservationObject.value(QStringLiteral("datetime")).toString(), "yyyy-MM-dd hh:mm:ss" );
+    const double longitude = weatherObservationObject.value(QStringLiteral("lng")).toDouble();
+    const double latitude = weatherObservationObject.value(QStringLiteral("lat")).toDouble();
 
     if ( !id.isEmpty() ) {
         WeatherData data;
 
         // Weather condition
-        if ( clouds != "n/a" && condition != "n/a" ) {
+        if (clouds != QLatin1String("n/a") && condition != QLatin1String("n/a")) {
             if ( dayConditions.contains( condition ) ) {
                 data.setCondition( dayConditions[condition] );
             } else {
@@ -169,7 +169,7 @@ AbstractDataPluginItem *GeoNamesWeatherService::parse( const QScriptValue &value
         data.setPublishingTime( date );
 
         // ID
-        id = "geonames_" + id;
+        id = QLatin1String("geonames_") + id;
 
         GeoDataCoordinates coordinates( longitude, latitude, 0.0, GeoDataCoordinates::Degree );
         GeoNamesWeatherItem *item = new GeoNamesWeatherItem( this );
@@ -181,7 +181,7 @@ AbstractDataPluginItem *GeoNamesWeatherService::parse( const QScriptValue &value
         item->setCurrentWeather( data );
         return item;
     } else {
-        return 0;
+        return nullptr;
     }
 }
 
