@@ -39,42 +39,42 @@ class WeatherPlugin : public AbstractDataPlugin, public DialogConfigurationInter
 
     explicit WeatherPlugin( const MarbleModel *marbleModel );
 
-    ~WeatherPlugin();
+    ~WeatherPlugin() override;
     
-    void initialize();
+    void initialize() override;
 
-    QString name() const;
+    QString name() const override;
     
-    QString guiString() const;
+    QString guiString() const override;
 
-    QString nameId() const;
+    QString nameId() const override;
     
-    QString version() const;
+    QString version() const override;
 
-    QString description() const;
+    QString description() const override;
 
-    QString copyrightYears() const;
+    QString copyrightYears() const override;
 
     QVector<PluginAuthor> pluginAuthors() const override;
 
-    QString aboutDataText() const;
+    QString aboutDataText() const override;
 
-    QIcon icon() const;
+    QIcon icon() const override;
 
-    QDialog *configDialog();
+    QDialog *configDialog() override;
 
-    QHash<QString,QVariant> settings() const;
+    QHash<QString,QVariant> settings() const override;
 
-    void setSettings( const QHash<QString,QVariant> &settings );
+    void setSettings( const QHash<QString,QVariant> &settings ) override;
 
 protected:
-    bool eventFilter(QObject *object, QEvent *event);
+    bool eventFilter(QObject *object, QEvent *event) override;
 
  private Q_SLOTS:
     void readSettings();
     void writeSettings();
     void updateItemSettings();
-    void favoriteItemsChanged( const QStringList& favoriteItems );
+    void favoriteItemsChanged( const QStringList& favoriteItems ) override;
     
  Q_SIGNALS:
     void changedSettings();
