@@ -24,8 +24,8 @@ class CycleStreetsConfigWidget : public RoutingRunnerPlugin::ConfigWidget
 
 public:
     CycleStreetsConfigWidget();
-    virtual void loadSettings( const QHash<QString, QVariant> &settings );
-    virtual QHash<QString, QVariant> settings() const;
+    void loadSettings( const QHash<QString, QVariant> &settings ) override;
+    QHash<QString, QVariant> settings() const override;
 
 private:
     Ui::CycleStreetsConfigWidget *ui_configWidget;
@@ -40,7 +40,6 @@ CycleStreetsConfigWidget::CycleStreetsConfigWidget()
     ui_configWidget->plan->addItem( tr( "balanced" ), "balanced" );
     ui_configWidget->plan->addItem( tr( "fastest" ), "fastest" );
     ui_configWidget->plan->addItem( tr( "quietest" ), "quietest" );
-    ui_configWidget->plan->addItem( tr( "shortest" ), "shortest" );
 
     if ( MarbleGlobal::getInstance()->locale()->measurementSystem() == MarbleLocale::MetricSystem ) {
         ui_configWidget->speed->addItem( tr( "slow (16 km/h)" ), "16" );
@@ -136,9 +135,7 @@ RoutingRunnerPlugin::ConfigWidget *CycleStreetsPlugin::configWidget()
 
 bool CycleStreetsPlugin::supportsTemplate( RoutingProfilesModel::ProfileTemplate profileTemplate ) const
 {
-    QSet<RoutingProfilesModel::ProfileTemplate> availableTemplates;
-    availableTemplates.insert( RoutingProfilesModel::BicycleTemplate );
-    return availableTemplates.contains( profileTemplate );
+    return profileTemplate == RoutingProfilesModel::BicycleTemplate;
 }
 
 }
