@@ -16,8 +16,8 @@
 #include "routing/RouteRequest.h"
 #include "routing/instructions/WaypointParser.h"
 #include "routing/instructions/InstructionTransformation.h"
-#include "GeoDataDocument.h"
 #include "GeoDataExtendedData.h"
+#include "GeoDataData.h"
 #include "GeoDataPlacemark.h"
 
 #include <QProcess>
@@ -40,7 +40,7 @@ public:
 GosmoreRunnerPrivate::GosmoreRunnerPrivate()
 {
     m_parser.setLineSeparator("\r");
-    m_parser.setFieldSeparator(',');
+    m_parser.setFieldSeparator(QLatin1Char(','));
     m_parser.setFieldIndex( WaypointParser::RoadName, 4 );
     m_parser.addJunctionTypeMapping( "Jr", RoutingWaypoint::Roundabout );
 }
@@ -74,7 +74,7 @@ GosmoreRunner::GosmoreRunner( QObject *parent ) :
         d( new GosmoreRunnerPrivate )
 {
     // Check installation
-    QDir mapDir( MarbleDirs::localPath() + "/maps/earth/gosmore/" );
+    QDir mapDir(MarbleDirs::localPath() + QLatin1String("/maps/earth/gosmore/"));
     d->m_gosmoreMapFile = QFileInfo ( mapDir, "gosmore.pak" );
 }
 
@@ -100,14 +100,14 @@ void GosmoreRunner::reverseGeocoding( const GeoDataCoordinates &coordinates )
     GeoDataPlacemark placemark;
     placemark.setCoordinate( coordinates );
 
-    QStringList lines = QString::fromUtf8( output ).split( '\r' );
+    QStringList lines = QString::fromUtf8(output).split(QLatin1Char('\r'));
     if ( lines.size() > 2 ) {
-        QStringList fields = lines.at( lines.size()-2 ).split(',');
+        QStringList fields = lines.at( lines.size()-2 ).split(QLatin1Char(','));
         if ( fields.size() >= 5 ) {
             QString road = fields.last().trimmed();
             placemark.setAddress( road );
             GeoDataExtendedData extendedData;
-            extendedData.addValue( GeoDataData( "road", road ) );
+            extendedData.addValue(GeoDataData(QStringLiteral("road"), road));
             placemark.setExtendedData( extendedData );
         }
     }
