@@ -101,7 +101,7 @@ GeoDataLineString GosmoreRunnerPrivate::parseGosmoreOutput( const QByteArray &co
     GeoDataLineString routeWaypoints;
 
     QStringList lines = QString::fromLocal8Bit( content ).split(QLatin1Char('\r'));
-    foreach( const QString &line, lines ) {
+    for( const QString &line: lines ) {
         const QStringList fields = line.split(QLatin1Char(','));
         if (fields.size() >= 5) {
             qreal lon = fields.at(1).toDouble();
@@ -164,7 +164,7 @@ QVector<GeoDataPlacemark*> GosmoreRunnerPrivate::parseGosmoreInstructions( const
 GeoDataDocument* GosmoreRunnerPrivate::createDocument( GeoDataLineString* routeWaypoints, const QVector<GeoDataPlacemark*> instructions )
 {
     if ( !routeWaypoints || routeWaypoints->isEmpty() ) {
-        return 0;
+        return nullptr;
     }
 
     GeoDataDocument* result = new GeoDataDocument();
@@ -182,7 +182,7 @@ GeoDataDocument* GosmoreRunnerPrivate::createDocument( GeoDataLineString* routeW
     }
     result->setName( name.arg( length, 0, 'f', 1 ).arg( unit ) );
 
-    foreach( GeoDataPlacemark* placemark, instructions )
+    for( GeoDataPlacemark* placemark: instructions )
     {
         result->append( placemark );
     }
@@ -208,7 +208,7 @@ void GosmoreRunner::retrieveRoute( const RouteRequest *route )
 {
     if ( !d->m_gosmoreMapFile.exists() )
     {
-        emit routeCalculated( 0 );
+        emit routeCalculated( nullptr );
         return;
     }
 
