@@ -32,7 +32,7 @@ GeoDataDocument *GpsbabelRunner::parseFile(const QString &fileName, DocumentRole
 {
     // Check and see if the file exists
     if ( !QFileInfo( fileName ).exists() ) {
-        error = QString("File %1 does not exist").arg(fileName);
+        error = QStringLiteral("File %1 does not exist").arg(fileName);
         mDebug() << error;
         return nullptr;
     }
@@ -51,23 +51,31 @@ GeoDataDocument *GpsbabelRunner::parseFile(const QString &fileName, DocumentRole
     fileTypes["csv"]      = "csv";
     QString const inputFileType = fileTypes[fileSuffix];
     if ( inputFileType.isEmpty() ) {
-        error = QString("Unsupported file extension for").arg(fileName);
+        error = QStringLiteral("Unsupported file extension for").arg(fileName);
         mDebug() << error;
         return nullptr;
     }
 
     // Set up temporary file to hold output KML from gpsbabel executable
-    QTemporaryFile tempKmlFile( QDir::tempPath() + "/marble-gpsbabel-XXXXXX.kml" );
+    QTemporaryFile tempKmlFile(QDir::tempPath() + QLatin1String("/marble-gpsbabel-XXXXXX.kml"));
     tempKmlFile.open();
     QFile kmlFile( tempKmlFile.fileName() );
 
     // Set up gpsbabel command line
-    QString command = "gpsbabel -i " + inputFileType;
-    command += " -f " + fileName + " -o kml -F ";
-    command += tempKmlFile.fileName();
+    const QString command = QLatin1String("gpsbabel");
+    const QStringList args = QStringList()
+        << QLatin1String("-i")
+        << inputFileType
+        << QLatin1String("-f")
+        << fileName
+        << QLatin1String("-o")
+        << QLatin1String("kml")
+        << QLatin1String("-F")
+        << tempKmlFile.fileName()
+    ;
 
     // Execute gpsbabel to parse the input file
-    int const exitStatus = QProcess::execute( command );
+    int const exitStatus = QProcess::execute( command, args );
     if ( exitStatus == 0 ) {
         kmlFile.open( QIODevice::ReadWrite );
         GeoDataParser parser( GeoData_KML );
@@ -82,7 +90,7 @@ GeoDataDocument *GpsbabelRunner::parseFile(const QString &fileName, DocumentRole
         document->setDocumentRole( role );
         return document;
     } else {
-        error = QString("Gpsbabel returned error code %1").arg(exitStatus);
+        error = QStringLiteral("Gpsbabel returned error code %1").arg(exitStatus);
         mDebug() << error;
         return nullptr;
     }
