@@ -21,7 +21,7 @@ namespace gpx
 class GPXextensionsTagHandler : public GeoTagHandler
 {
 public:
-    virtual GeoNode* parse(GeoParser&) const;
+    GeoNode* parse(GeoParser&) const override;
 };
 
 }
