@@ -48,7 +48,7 @@ GeoNode* GPXtrksegTagHandler::parse(GeoParser& parser) const
         multigeometry->append( track );
         return track;
     }
-    return 0;
+    return nullptr;
 }
 
 } // namespace gpx
