@@ -13,11 +13,11 @@
 
 #include "GeoDataPoint.h"
 #include "GeoDataLinearRing.h"
+#include "GeoDataMultiGeometry.h"
 #include <GeoDataParser.h>
 #include <GeoDataDocument.h>
 #include <GeoDataPlacemark.h>
 #include <MarbleDebug.h>
-#include <GeoDataFolder.h>
 #include <GeoDataTrack.h>
 #include <GeoDataExtendedData.h>
 #include <GeoDataSimpleArrayData.h>
