@@ -24,25 +24,25 @@ class HostipPlugin : public SearchRunnerPlugin
     Q_INTERFACES( Marble::SearchRunnerPlugin )
 
 public:
-    explicit HostipPlugin( QObject *parent = 0 );
+    explicit HostipPlugin( QObject *parent = nullptr );
 
-    QString name() const;
+    QString name() const override;
 
-    QString guiString() const;
+    QString guiString() const override;
 
-    QString nameId() const;
+    QString nameId() const override;
 
-    QString version() const;
+    QString version() const override;
 
-    QString description() const;
+    QString description() const override;
 
-    QString copyrightYears() const;
+    QString copyrightYears() const override;
 
     QVector<PluginAuthor> pluginAuthors() const override;
 
-    virtual SearchRunner* newRunner() const;
+    SearchRunner* newRunner() const override;
 
-    bool canWork() const;
+    bool canWork() const override;
 };
 
 }
