@@ -18,7 +18,7 @@ namespace Marble
 NominatimPlugin::NominatimPlugin( QObject *parent ) :
     ReverseGeocodingRunnerPlugin( parent )
 {
-    setSupportedCelestialBodies( QStringList() << "earth" );
+    setSupportedCelestialBodies(QStringList(QStringLiteral("earth")));
     setCanWorkOffline( false );
 }
 
@@ -34,12 +34,12 @@ QString NominatimPlugin::guiString() const
 
 QString NominatimPlugin::nameId() const
 {
-    return "nominatim-reverse";
+    return QStringLiteral("nominatim-reverse");
 }
 
 QString NominatimPlugin::version() const
 {
-    return "1.0";
+    return QStringLiteral("1.0");
 }
 
 QString NominatimPlugin::description() const
@@ -49,14 +49,14 @@ QString NominatimPlugin::description() const
 
 QString NominatimPlugin::copyrightYears() const
 {
-    return "2010, 2012";
+    return QStringLiteral("2010, 2012");
 }
 
-QList<PluginAuthor> NominatimPlugin::pluginAuthors() const
+QVector<PluginAuthor> NominatimPlugin::pluginAuthors() const
 {
-    return QList<PluginAuthor>()
-            << PluginAuthor( QString::fromUtf8( "Dennis Nienhüser" ), "nienhueser@kde.org" )
-            << PluginAuthor( "Bernhard Beschow", "bbeschow@cs.tu-berlin.de" );
+    return QVector<PluginAuthor>()
+            << PluginAuthor(QStringLiteral("Dennis Nienhüser"), QStringLiteral("nienhueser@kde.org"))
+            << PluginAuthor(QStringLiteral("Bernhard Beschow"), QStringLiteral("bbeschow@cs.tu-berlin.de"));
 }
 
 ReverseGeocodingRunner* NominatimPlugin::newRunner() const
@@ -66,6 +66,4 @@ ReverseGeocodingRunner* NominatimPlugin::newRunner() const
 
 }
 
-Q_EXPORT_PLUGIN2( NominatimReverseGeocodingPlugin, Marble::NominatimPlugin )
-
 #include "moc_NominatimReverseGeocodingPlugin.cpp"
