@@ -9,8 +9,8 @@
 //
 
 
-#ifndef MARBLE_OSMNOMINATIMRUNNER_H
-#define MARBLE_OSMNOMINATIMRUNNER_H
+#ifndef MARBLE_OSMNOMINATIMREVERSEGEOCODINGRUNNER_H
+#define MARBLE_OSMNOMINATIMREVERSEGEOCODINGRUNNER_H
 
 #include "ReverseGeocodingRunner.h"
 #include "GeoDataCoordinates.h"
