@@ -9,8 +9,8 @@
 //
 
 
-#ifndef MARBLE_OSMNOMINATIMRUNNER_H
-#define MARBLE_OSMNOMINATIMRUNNER_H
+#ifndef MARBLE_OSMNOMINATIMSEARCHRUNNER_H
+#define MARBLE_OSMNOMINATIMSEARCHRUNNER_H
 
 #include "SearchRunner.h"
 
