@@ -17,7 +17,7 @@ namespace Marble
 OSRMPlugin::OSRMPlugin( QObject *parent ) :
     RoutingRunnerPlugin( parent )
 {
-    setSupportedCelestialBodies( QStringList() << "earth" );
+    setSupportedCelestialBodies(QStringList(QStringLiteral("earth")));
     setCanWorkOffline( false );
     setStatusMessage( tr ( "This service requires an Internet connection." ) );
 }
@@ -34,12 +34,12 @@ QString OSRMPlugin::guiString() const
 
 QString OSRMPlugin::nameId() const
 {
-    return "osrm";
+    return QStringLiteral("osrm");
 }
 
 QString OSRMPlugin::version() const
 {
-    return "1.0";
+    return QStringLiteral("1.0");
 }
 
 QString OSRMPlugin::description() const
@@ -49,13 +49,13 @@ QString OSRMPlugin::description() const
 
 QString OSRMPlugin::copyrightYears() const
 {
-    return "2012";
+    return QStringLiteral("2012");
 }
 
-QList<PluginAuthor> OSRMPlugin::pluginAuthors() const
+QVector<PluginAuthor> OSRMPlugin::pluginAuthors() const
 {
-    return QList<PluginAuthor>()
-            << PluginAuthor( QString::fromUtf8( "Dennis Nienhüser" ), "nienhueser@kde.org" );
+    return QVector<PluginAuthor>()
+            << PluginAuthor(QStringLiteral("Dennis Nienhüser"), QStringLiteral("nienhueser@kde.org"));
 }
 
 RoutingRunner *OSRMPlugin::newRunner() const
