@@ -35,7 +35,7 @@ namespace Marble
 class FITemplateFloatItem  : public AbstractFloatItem
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA( IID "org.kde.edu.marble.FITemplateFloatItem" )
+    Q_PLUGIN_METADATA(IID "org.kde.marble.FITemplateFloatItem")
     Q_INTERFACES( Marble::RenderPluginInterface )
     MARBLE_PLUGIN(FITemplateFloatItem)
 
