@@ -14,6 +14,8 @@
 #include "MarbleZipReader.h"
 #include <GeoDataLatLonAltBox.h>
 #include "PeakAnalyzer.h"
+#include "TileCoordsPyramid.h"
+#include "StyleBuilder.h"
 
 #include <QFileInfo>
 #include <QDebug>
@@ -31,6 +33,8 @@ using namespace std;
 
 namespace Marble {
 
+QMap<int, TagsFilter::Tags> TileDirectory::m_tags;
+
 TileDirectory::TileDirectory(TileType tileType, const QString &cacheDir, ParsingRunnerManager &manager, QString const &extension, int maxZoomLevel) :
     m_cacheDir(cacheDir),
     m_baseDir(),
@@ -111,7 +115,9 @@ void TileDirectory::setInputFile(const QString &filename)
             m_inputFile = cacheFile.absoluteFilePath();
 
             QString polyFile = QUrl(filename).fileName();
-            polyFile.remove("-latest.osm.pbf").append(".poly");
+            polyFile.replace("-latest.osm.pbf", ".poly");
+            polyFile.replace(".osm.pbf", ".poly");
+            polyFile.replace(".pbf", ".poly");
             QString poly = QString("%1/%2").arg(url.adjusted(QUrl::RemoveFilename).toString()).arg(polyFile);
             QString const polyTarget = QString("%1/%2").arg(m_cacheDir).arg(polyFile);
             if (!QFileInfo(polyTarget).exists()) {
@@ -152,105 +158,32 @@ QSharedPointer<GeoDataDocument> TileDirectory::open(const QString &filename, Par
     return result;
 }
 
-QStringList TileDirectory::tagsFilteredIn(int zoomLevel) const
+TagsFilter::Tags TileDirectory::tagsFilteredIn(int zoomLevel) const
 {
-    QStringList tags;
-    tags << "highway=motorway" << "highway=motorway_link";
-    tags << "highway=trunk" << "highway=trunk_link";
-    tags << "highway=primary" << "highway=primary_link";
-    tags << "highway=secondary" << "highway=secondary_link";
+    if (m_tags.isEmpty()) {
+        QSet<GeoDataPlacemark::GeoDataVisualCategory> categories;
+        for (int i=GeoDataPlacemark::PlaceCity; i<GeoDataPlacemark::LastIndex; ++i) {
+            categories << GeoDataPlacemark::GeoDataVisualCategory(i);
+        }
 
-    tags << "natural=glacier";
-    tags << "natural=water";
-    tags << "waterway=river";
-    tags << "waterway=riverbank";
-    tags << "waterway=canal";
-
-    if (zoomLevel >= 13) {
-        tags << "highway=tertiary" << "highway=tertiary_link";
-        tags << "highway=unclassified";
-
-        tags << "public_transport=station";
-        tags << "railway=light_rail";
-        tags << "railway=monorail";
-        tags << "railway=narrow_gauge";
-        tags << "railway=preserved";
-        tags << "railway=rail";
-        tags << "railway=subway";
-        tags << "railway=tram";
-
-        tags << "natural=scrub";
-        tags << "natural=heath";
-        tags << "natural=grassland";
-        tags << "natural=beach";
-        tags << "natural=coastline";
-        tags << "leisure=stadium";
-        tags << "tourism=alpine_hut";
-
-        tags << "place=suburb";
-        tags << "place=village";
-        tags << "amenity=hospital";
+        auto const tagMap = StyleBuilder::osmTagMapping();
+        for (auto category: categories) {
+            for (auto iter=tagMap.begin(), end=tagMap.end(); iter != end; ++iter) {
+                if (iter.value() == category) {
+                    int zoomLevel = StyleBuilder::minimumZoomLevel(category);
+                    if (zoomLevel < 17) {
+                        m_tags[zoomLevel] << iter.key();
+                    }
+                }
+            }
+        }
     }
 
-    if (zoomLevel <= 11) {
-        tags << "landuse=forest";
-        tags << "landuse=military";
-        tags << "landuse=residential";
-    } else if (zoomLevel <= 13) {
-        tags << "landuse=commercial";
-        tags << "landuse=farmland";
-        tags << "landuse=farmyard";
-        tags << "landuse=forest";
-        tags << "landuse=industrial";
-        tags << "landuse=meadow";
-        tags << "landuse=military";
-        tags << "landuse=recreation_ground";
-        tags << "landuse=residential";
-        tags << "landuse=retail";
+    TagsFilter::Tags result;
+    for (auto iter = m_tags.begin(), end = m_tags.end(); iter != end && iter.key() <= zoomLevel+1; ++iter) {
+        result << iter.value();
     }
-
-    if (zoomLevel >= 15) {
-        tags << "waterway=stream";
-
-        tags << "highway=residential";
-        tags << "highway=track";
-
-        tags << "landuse=*";
-
-        tags << "leisure=pitch";
-        tags << "leisure=swimming_area";
-
-        tags << "place=hamlet";
-        tags << "place=isolated_dwelling";
-
-        tags << "man_made=beacon";
-        tags << "man_made=bridge";
-        tags << "man_made=campanile";
-        tags << "man_made=chimney";
-        tags << "man_made=communications_tower";
-        tags << "man_made=cross";
-        tags << "man_made=gasometer";
-        tags << "man_made=lighthouse";
-        tags << "man_made=tower";
-        tags << "man_made=water_tower";
-        tags << "man_made=windmill";
-    }
-
-    tags << "natural=peak";
-    tags << "natural=wood";
-
-    tags << "leisure=nature_reserve";
-    tags << "leisure=park";
-
-    tags << "place=city";
-    tags << "place=town";
-    tags << "place=locality";
-
-    tags << "boundary=administrative";
-    tags << "boundary=political";
-    tags << "boundary=national_park";
-    tags << "boundary=protected_area";
-    return tags;
+    return result;
 }
 
 void TileDirectory::setTagZoomLevel(int zoomLevel)
@@ -258,8 +191,8 @@ void TileDirectory::setTagZoomLevel(int zoomLevel)
     m_tagZoomLevel = zoomLevel;
     if (m_tileType == OpenStreetMap) {
         if (m_tagZoomLevel < 17) {
-            QStringList const tags = tagsFilteredIn(m_tagZoomLevel);
-            m_tagsFilter = QSharedPointer<TagsFilter>(new TagsFilter(m_landmass.data(), tags));
+            auto const tags = tagsFilteredIn(m_tagZoomLevel);
+            m_tagsFilter = QSharedPointer<TagsFilter>(new TagsFilter(m_landmass.data(), tags, TagsFilter::FilterRailwayService));
         } else {
             m_tagsFilter.clear();
         }
@@ -279,6 +212,12 @@ void TileDirectory::download(const QString &url, const QString &target)
     cout << endl;
 }
 
+QString TileDirectory::osmFileFor(const TileId &tileId) const
+{
+    QString const outputDir = QString("%1/osm/%2/%3").arg(m_cacheDir).arg(tileId.zoomLevel()).arg(tileId.x());
+    return QString("%1/%2.o5m").arg(outputDir).arg(tileId.y());
+}
+
 void TileDirectory::printProgress(double progress, int barWidth)
 {
     int const position = barWidth * progress;
@@ -342,16 +281,23 @@ void TileDirectory::setBoundingPolygon(const QString &file)
         for (int i=1, n=m_boundingPolygon.size(); i<n; ++i) {
             m_boundingBox |= GeoDataLatLonBox::fromLineString(m_boundingPolygon[i]);
         }
+    } else {
+        m_boundingBox = boundingBox(m_inputFile);
     }
 }
 
 void TileDirectory::createTiles() const
 {
+    if (m_tileType == OpenStreetMap) {
+        createOsmTiles();
+        return;
+    }
+
     QSharedPointer<GeoDataDocument> map;
     QSharedPointer<VectorClipper> clipper;
     TileIterator iter(m_boundingBox, m_zoomLevel);
     qint64 count = 0;
-    foreach(auto const &tileId, iter) {
+    for(auto const &tileId: iter) {
         ++count;
         QString const outputDir = QString("%1/%2").arg(m_baseDir).arg(tileId.x());
         QString const outputFile = QString("%1/%2.o5m").arg(outputDir).arg(tileId.y());
@@ -360,50 +306,113 @@ void TileDirectory::createTiles() const
         }
 
         printProgress(count / double(iter.total()));
-        cout << " Creating " << (m_tileType == OpenStreetMap ? "osm" : "landmass");
-        cout << " cache tile " << count << "/" << iter.total() << " (";
-        cout << m_zoomLevel << "/" << tileId.x() << "/" << tileId.y() << ")      \r";
+        cout << " Creating landmass cache tile " << count << "/" << iter.total() << " (";
+        cout << m_zoomLevel << "/" << tileId.x() << "/" << tileId.y() << ')' << string(20, ' ') << '\r';
         cout.flush();
 
         QDir().mkpath(outputDir);
-        if (m_tileType == OpenStreetMap) {
-            QString const output = QString("-o=%1").arg(outputFile);
-
-            GeoDataLatLonBox tileBoundary;
-            m_tileProjection.geoCoordinates(m_zoomLevel, tileId.x(), tileId.y(), tileBoundary);
-
-            double const minLon = tileBoundary.west(GeoDataCoordinates::Degree);
-            double const maxLon = tileBoundary.east(GeoDataCoordinates::Degree);
-            double const maxLat = tileBoundary.north(GeoDataCoordinates::Degree);
-            double const minLat = tileBoundary.south(GeoDataCoordinates::Degree);
-            QString const bbox = QString("-b=%1,%2,%3,%4").arg(minLon).arg(minLat).arg(maxLon).arg(maxLat);
-            QProcess osmconvert;
-            osmconvert.start("osmconvert", QStringList() << "--drop-author" << "--drop-version"
-                             << "--complete-ways" << "--complex-ways" << bbox << output << m_inputFile);
-            osmconvert.waitForFinished(10*60*1000);
-            if (osmconvert.exitCode() != 0) {
-                qWarning() << osmconvert.readAllStandardError();
-                qWarning() << "osmconvert failed: " << osmconvert.errorString();
-            }
-        } else {
+        if (!clipper) {
+            map = open(m_inputFile, m_manager);
             if (!map) {
-                map = open(m_inputFile, m_manager);
-                clipper = QSharedPointer<VectorClipper>(new VectorClipper(map.data(), m_zoomLevel));
-            }
-            auto tile = clipper->clipTo(m_zoomLevel, tileId.x(), tileId.y());
-            if (!GeoDataDocumentWriter::write(outputFile, *tile)) {
-                qWarning() << "Failed to write tile" << outputFile;
+                qCritical() << "Failed to open " << m_inputFile << ". This can happen when Marble was compiled without shapelib (libshp), when the system has too little memory (RAM + swap need to be at least 8G), or when the download of the landmass data file failed.";
             }
+            clipper = QSharedPointer<VectorClipper>(new VectorClipper(map.data(), m_zoomLevel));
+        }
+        auto tile = clipper->clipTo(m_zoomLevel, tileId.x(), tileId.y());
+        if (!GeoDataDocumentWriter::write(outputFile, *tile)) {
+            qWarning() << "Failed to write tile" << outputFile;
         }
     }
     printProgress(1.0);
-    cout << "  " << (m_tileType == OpenStreetMap ? "osm" : "landmass") << " cache tiles complete." << endl;
+    cout << "  landmass cache tiles complete." << string(20, ' ') << endl;
+}
+
+void TileDirectory::createOsmTiles() const
+{
+    const GeoSceneMercatorTileProjection tileProjection;
+    const QRect rect = tileProjection.tileIndexes(m_boundingBox, m_zoomLevel);
+    TileCoordsPyramid pyramid(0, m_zoomLevel);
+    pyramid.setBottomLevelCoords(rect);
+
+    qint64 const maxCount = pyramid.tilesCount();
+    QMap<int,QVector<TileId> > tileLevels;
+    for (int zoomLevel=0; zoomLevel <= m_zoomLevel; ++zoomLevel) {
+        QRect const rect = pyramid.coords(zoomLevel);
+        if (zoomLevel < m_zoomLevel && rect.width()*rect.height() < 2) {
+            continue;
+        }
+
+        TileIterator iter(m_boundingBox, zoomLevel);
+        for(auto const &tileId: iter) {
+            tileLevels[zoomLevel] << TileId(0, zoomLevel, tileId.x(), tileId.y());
+        }
+    }
+
+    bool hasAllTiles = true;
+    for (auto const &tileId: tileLevels[m_zoomLevel]) {
+        auto const outputFile = osmFileFor(tileId);
+        if (!QFileInfo(outputFile).exists()) {
+            hasAllTiles = false;
+            break;
+        }
+    }
+
+    bool first = true;
+    if (!hasAllTiles) {
+        qint64 count = 0;
+        for (auto const &tiles: tileLevels) {
+            for (auto const &tileId: tiles) {
+                ++count;
+                QString const inputFile = first ? m_inputFile : QString("%1/osm/%2/%3/%4.o5m").
+                                                  arg(m_cacheDir).arg(tileId.zoomLevel()-1).arg(tileId.x()>>1).arg(tileId.y()>>1);
+                QString const outputFile = osmFileFor(tileId);
+                if (QFileInfo(outputFile).exists()) {
+                    continue;
+                }
+
+                printProgress(count / double(maxCount));
+                cout << " Creating osm cache tile " << count << "/" << maxCount << " (";
+                cout << tileId.zoomLevel() << "/" << tileId.x() << "/" << tileId.y() << ')' << string(20, ' ') << '\r';
+                cout.flush();
+
+                QDir().mkpath(QFileInfo(outputFile).absolutePath());
+                QString const output = QString("-o=%1").arg(outputFile);
+
+                const GeoDataLatLonBox tileBoundary = m_tileProjection.geoCoordinates(tileId.zoomLevel(), tileId.x(), tileId.y());
+
+                double const minLon = tileBoundary.west(GeoDataCoordinates::Degree);
+                double const maxLon = tileBoundary.east(GeoDataCoordinates::Degree);
+                double const maxLat = tileBoundary.north(GeoDataCoordinates::Degree);
+                double const minLat = tileBoundary.south(GeoDataCoordinates::Degree);
+                QString const bbox = QString("-b=%1,%2,%3,%4").arg(minLon).arg(minLat).arg(maxLon).arg(maxLat);
+                QProcess osmconvert;
+                osmconvert.start("osmconvert", QStringList() << "--drop-author" << "--drop-version"
+                                 << "--complete-ways" << "--complex-ways" << bbox << output << inputFile);
+                osmconvert.waitForFinished(10*60*1000);
+                if (osmconvert.exitCode() != 0) {
+                    qWarning() << osmconvert.readAllStandardError();
+                    qWarning() << "osmconvert failed: " << osmconvert.errorString();
+                }
+            }
+            first = false;
+        }
+    }
+
+    tileLevels.remove(m_zoomLevel);
+    for (auto const &tiles: tileLevels) {
+        for (auto const &tileId: tiles) {
+            QFile::remove(osmFileFor(tileId));
+        }
+    }
+
+    printProgress(1.0);
+    cout << "  osm cache tiles complete." << string(20, ' ') << endl;
+
 }
 
 int TileDirectory::innerNodes(const TileId &tile) const
 {
-    GeoDataLatLonBox tileBoundary;
-    m_tileProjection.geoCoordinates(tile.zoomLevel(), tile.x(), tile.y(), tileBoundary);
+    const GeoDataLatLonBox tileBoundary = m_tileProjection.geoCoordinates(tile.zoomLevel(), tile.x(), tile.y());
 
     double const west = tileBoundary.west();
     double const east = tileBoundary.east();
@@ -417,7 +426,7 @@ int TileDirectory::innerNodes(const TileId &tile) const
 
     int innerNodes = 0;
     if (m_boundingPolygon.isEmpty()) {
-        foreach(auto const &coordinate, bounds) {
+        for(auto const &coordinate: bounds) {
             if (m_boundingBox.contains(coordinate)) {
                 ++innerNodes;
             }
@@ -425,8 +434,8 @@ int TileDirectory::innerNodes(const TileId &tile) const
         return innerNodes;
     }
 
-    foreach(auto const &coordinate, bounds) {
-        foreach(auto const &ring, m_boundingPolygon) {
+    for(auto const &coordinate: bounds) {
+        for(auto const &ring: m_boundingPolygon) {
             if (ring.contains(coordinate)) {
                 ++innerNodes;
             }
@@ -446,7 +455,7 @@ void TileDirectory::updateProgress()
 
     cout << "  Downloading " << m_download->reply->url().fileName().toStdString();
 
-    cout << "    \r";
+    cout << string(20, ' ') << '\r';
     cout.flush();
 }
 
@@ -462,7 +471,7 @@ GeoDataLatLonBox TileDirectory::boundingBox(const QString &filename) const
     osmconvert.waitForFinished(10*60*1000);
     QStringList const output = QString(osmconvert.readAllStandardOutput()).split('\n');
     GeoDataLatLonBox boundingBox;
-    foreach(QString const &line, output) {
+    for(QString const &line: output) {
         if (line.startsWith("lon min:")) {
             boundingBox.setWest(line.mid(8).toDouble(), GeoDataCoordinates::Degree);
         } else if (line.startsWith("lon max")) {
